@@ -63,7 +63,8 @@ def test_cli_offline(
     user_config,
     cli_invoker_params,
     assert_files_committed_if_flag_is_on,
-    assert_generated_expected_project_type,
+    get_expected_generated_files,
+    project_files,
     isolated_cli_runner,
     tmp_path,
 ):
@@ -133,7 +134,17 @@ def test_cli_offline(
 
     assert_files_committed_if_flag_is_on(gen_proj_dir, config)
 
-    assert_generated_expected_project_type(project_dir, config)
+    # Assert Files found at runtime in Generated Project Root Dir are the expected ones
+    runtime_generated_files = set(project_files(project_dir).relative_file_paths())
+    expected_gen_files: t.Set[Path] = set(get_expected_generated_files(config))
+
+    # TODO: obviously, remove if, with deterministic test config to control all aspect of Logs
+    if Path('cookie-py.log') in runtime_generated_files:
+        runtime_generated_files.remove(Path('cookie-py.log'))
+        logger.warning(
+            "Test code issue: cookie-py.log found in set of files, reported by the test code that reads the runtime directory of Gen Proj Dir"
+        )
+    assert runtime_generated_files == expected_gen_files
 
     # disable hard-bypass of error/bug
     # assert not path.exists(path.join(project_dir, 'cookie-py.log')), f"Gen Logs Found in Gen Target Dir! File Contents as string:\n\n{open(path.join(project_dir, 'cookie-py.log')).read()}"
@@ -149,38 +160,6 @@ def test_cli_offline(
     )
 
 
-@pytest.fixture
-def assert_generated_expected_project_type(
-    project_files,
-    get_expected_generated_files,
-):
-    def _assert_generated_expected_project_type(project_dir: str, config):
-        runtime_generated_files = set(project_files(project_dir).relative_file_paths())
-        expected_gen_files: t.Set[Path] = set(
-            get_expected_generated_files(project_dir, config)
-        )
-
-        # TODO: obviously, remove if, with deterministic test config to control all aspect of Logs
-        if Path('cookie-py.log') in runtime_generated_files:
-            runtime_generated_files.remove(Path('cookie-py.log'))
-            logger.warning(
-                "Test code issue: cookie-py.log found in set of files, reported by the test code that reads the runtime directory of Gen Proj Dir"
-            )
-        # expectation = expected_gen_files
-        # if config.data['initialize_git_repo'] is True:  # conditon, recognized as prerequisite for the BUG to appear
-        #     # somehow the cookiecutter_python logs file (cookie-py.log) included
-        #     # in the set of files (not dirs), reported by the test code that
-        #     # reads the runtime directory of Gen Proj Dir
-
-        #     # bypass by adding the file to the expected set of files
-        #     expectation = expected_gen_files.union({Path('cookie-py.log')})
-        #     # verify expectation has more items than expected_gen_files
-        #     assert len(expectation) > len(expected_gen_files)
-        assert runtime_generated_files == expected_gen_files
-
-    return _assert_generated_expected_project_type
-
-
 @pytest.fixture
 def check_pypi_result(check_web_server) -> t.Callable[[str], t.Optional[bool]]:
     check_pypi_output = {
